import express, { Express } from "express";
import cors from "cors";
import mongoose from "mongoose";
import compression from "compression";

import routes from "./routes/v1";

/**
 * Import .env file
 */
require("dotenv").config();

/**
 * Create App instance
 */
const app: Express = express();

/**
 * Middleware
 */
app.use(cors());
app.use(compression());

/**
 * APIs
 */
app.use("/v1", routes);

/**
 * Connect DB
 */
const URi: any = process.env.MONGO_URI;
console.log("URi", URi, typeof URi);

mongoose
  .connect(URi, {
    useNewUrlParser: true,
    useUnifiedTopology: true,
  })
  .then(() => console.log("👍 DB is Connected"))
  .catch((error) => console.error(error, "Failed to connect DB"));

/**
 * Configure Port and Run Server
 */
const PORT = process.env.PORT || 3000;
app.listen(PORT, () => console.log(`🎉 Server is Up on PORT=${PORT}`));
